import { Directive, HostListener } from '@angular/core';
export var NavDropdownDirective = (function () {
    function NavDropdownDirective() {
        this._open = false;
    }
    /**
     * Checks if the dropdown menu is open or not.
     */
    NavDropdownDirective.prototype.isOpen = function () {
        return this._open;
    };
    /**
     * Opens the dropdown menu.
     */
    NavDropdownDirective.prototype.open = function () {
        this._open = true;
    };
    /**
     * Closes the dropdown menu .
     */
    NavDropdownDirective.prototype.close = function () {
        this._open = false;
    };
    /**
     * Toggles the dropdown menu.
     */
    NavDropdownDirective.prototype.toggle = function () {
        if (this.isOpen()) {
            this.close();
        }
        else {
            this.open();
        }
    };
    NavDropdownDirective.decorators = [
        { type: Directive, args: [{
                    selector: '.nav-dropdown',
                    host: {
                        '[class.open]': '_open',
                    }
                },] },
    ];
    /** @nocollapse */
    NavDropdownDirective.ctorParameters = function () { return []; };
    return NavDropdownDirective;
}());
/**
 * Allows the dropdown to be toggled via click.
 */
export var NavDropdownToggleDirective = (function () {
    function NavDropdownToggleDirective(dropdown) {
        this.dropdown = dropdown;
    }
    NavDropdownToggleDirective.prototype.toggleOpen = function ($event) {
        $event.preventDefault();
        this.dropdown.toggle();
    };
    NavDropdownToggleDirective.decorators = [
        { type: Directive, args: [{
                    selector: '.nav-dropdown-toggle',
                },] },
    ];
    /** @nocollapse */
    NavDropdownToggleDirective.ctorParameters = function () { return [
        { type: NavDropdownDirective, },
    ]; };
    NavDropdownToggleDirective.propDecorators = {
        'toggleOpen': [{ type: HostListener, args: ['click', ['$event'],] },],
    };
    return NavDropdownToggleDirective;
}());
//# sourceMappingURL=nav.directives.js.map